@@ -6,24 +6,25 @@
 # See the file LICENSE for copying permission.
 
 import time
+import json
 import collections
 
 from boto.swf.exceptions import SWFResponseError, SWFTypeAlreadyExistsError
 
 from swf.constants import REGISTERED
-from swf.core import ConnectedSWFObject
 from swf.utils import immutable
 from swf.models import BaseModel
 from swf.models.history import History
 from swf.models.base import ModelDiff
-from swf.exceptions import DoesNotExistError, AlreadyExistsError,\
-                           ResponseError
+from swf.exceptions import (DoesNotExistError, AlreadyExistsError,
+                            ResponseError)
 
 
-_POLICIES = ('TERMINATE',       # child executions will be terminated
-             'REQUEST_CANCEL',  # a request to cancel will be attempted for
-                                # each child execution
-             'ABANDON',         # no action will be taken
+_POLICIES = (
+    'TERMINATE',       # child executions will be terminated
+    'REQUEST_CANCEL',  # a request to cancel will be attempted for
+                       # each child execution
+    'ABANDON',         # no action will be taken
 )
 
 CHILD_POLICIES = collections.namedtuple('CHILD_POLICY',
@@ -163,7 +164,7 @@ class WorkflowType(BaseModel):
         :rtype: bool
         """
         try:
-            description = self.connection.describe_workflow_type(
+            self.connection.describe_workflow_type(
                 self.domain.name,
                 self.name,
                 self.version
@@ -224,13 +225,13 @@ class WorkflowType(BaseModel):
                               of this workflow execution.
         :type   child_policy: CHILD_POLICIES.{TERMINATE |
                                               REQUEST_CANCEL |
-                                              ABANDON}
+                                        ABANDON}
 
         :param  execution_timeout: maximum duration for the workflow execution
         :type   execution_timeout: String
 
         :param  input: Input of the workflow execution
-        :type   input: String
+        :type   input: dict
 
         :param  tag_list: Tags associated with the workflow execution
         :type   tag_list: String
@@ -242,6 +243,7 @@ class WorkflowType(BaseModel):
         workflow_id = workflow_id or '%s-%s-%i' % (self.name, self.version, time.time())
         task_list = task_list or self.task_list
         child_policy = child_policy or self.child_policy
+        input = json.dumps(input) or None
 
         run_id = self.connection.start_workflow_execution(
             self.domain.name,
@@ -287,6 +289,14 @@ class WorkflowExecution(BaseModel):
     :param  status: Whether the WorkflowExecution instance represents an opened or
                     closed execution
     :type   status: String constant
+
+    :param  task_list: The task list to use for the decision tasks generated
+                       for this workflow execution.
+    :type   task_list: string
+
+    :param  input: input data of the execution, which will be passed around using
+                   serialized json
+    :type   input: dict
     """
     STATUS_OPEN = "OPEN"
     STATUS_CLOSED = "CLOSED"
@@ -360,9 +370,9 @@ class WorkflowExecution(BaseModel):
         return ModelDiff(
             ('workflow_id', self.workflow_id, execution_info['execution']['workflowId']),
             ('run_id', self.run_id, execution_info['execution']['runId']),
-            ('status',  self.status, execution_info['executionStatus']),
+            ('status', self.status, execution_info['executionStatus']),
             ('task_list', self.task_list, execution_config['taskList']['name']),
-            ('child_policy',  self.child_policy, execution_config['childPolicy']),
+            ('child_policy', self.child_policy, execution_config['childPolicy']),
             ('execution_timeout', self.execution_timeout, execution_config['executionStartToCloseTimeout']),
             ('tag_list', self.tag_list, execution_info.get('tagList')),
             ('decision_tasks_timeout', self.decision_tasks_timeout, execution_config['taskStartToCloseTimeout']),
@@ -375,7 +385,7 @@ class WorkflowExecution(BaseModel):
         :rtype: bool
         """
         try:
-            description = self.connection.describe_workflow_execution(
+            self.connection.describe_workflow_execution(
                 self.domain.name,
                 self.run_id,
                 self.workflow_id
@@ -421,14 +431,16 @@ class WorkflowExecution(BaseModel):
 
         :param  input: Data to attach to the WorkflowExecutionSignaled
                        event in the target workflow execution’s history.
-        :type   input: str
+        :type   input: dict
         """
+        input = json.dumps(input) or None
+
         try:
             self.connection.signal_workflow_execution(
                 self.domain.name,
                 signal_name,
                 self.workflow_id,
-                input=input,
+                input=json.dumps(input),
                 run_id=self.run_id)
         except SWFResponseError as e:
             if e.error_code == 'UnknownResourceFault':
@@ -468,6 +480,3 @@ class WorkflowExecution(BaseModel):
             raise ResponseError(e.body['message'])
 
         return
-
-
-
